@@ -227,25 +227,16 @@ impl Hash for AsdfBackend {
 }
 
 impl Backend for AsdfBackend {
-    fn ba(&self) -> &BackendArg {
-        &self.ba
-    }
-
     fn get_type(&self) -> BackendType {
         BackendType::Asdf
     }
 
-    fn get_plugin_type(&self) -> Option<PluginType> {
-        Some(PluginType::Asdf)
+    fn ba(&self) -> &BackendArg {
+        &self.ba
     }
 
-    fn get_dependencies(&self, tvr: &ToolRequest) -> Result<Vec<String>> {
-        let out = match tvr.ba().tool_name.as_str() {
-            "poetry" | "pipenv" | "pipx" => vec!["python"],
-            "elixir" => vec!["erlang"],
-            _ => vec![],
-        };
-        Ok(out.into_iter().map(|s| s.into()).collect())
+    fn get_plugin_type(&self) -> Option<PluginType> {
+        Some(PluginType::Asdf)
     }
 
     fn _list_remote_versions(&self) -> Result<Vec<String>> {
